@@ -472,7 +472,12 @@ class PatchEngine:
         if self.client is None:
             return
         
-        state, pos_dict = self.client.transport_query()
+        try:
+            state, pos_dict = self.client.transport_query()
+        except BaseException as e:
+            _logger.warning('Failed to send transport position, '
+                            f'transport_query() failed\n{str(e)}')
+            return
         
         if (self.transport_wanted is TransportWanted.STATE_ONLY
                 and bool(state) == self.last_transport_pos.rolling):
@@ -530,10 +535,9 @@ class PatchEngine:
     
     def set_buffer_size(self, blocksize: int):
         if self.client is None:
-            return
-        
+            return        
         self.client.blocksize = blocksize
-             
+
     def exit(self):
         self._save_uuid_pretty_names()
         
@@ -670,6 +674,37 @@ class PatchEngine:
             else:
                 self.patch_event_queue.add(
                     PatchEvent.PORT_REMOVED, port_name)
+            
+            # if not register:
+            #     return
+            
+            if self.client is None:
+                return
+            
+            # With PipeWire, some ports can be added (re-added in reality)
+            # with already existing connections, in the case of
+            # buffersize (quantum) change.
+            # So we check here existing connections of the port
+            try:
+                for cport in self.client.get_all_connections(port):
+                    cport_name = cport.name                    
+                    if register:
+                        event = PatchEvent.CONNECTION_ADDED
+                    else:
+                        event = PatchEvent.CONNECTION_REMOVED
+                    
+                    if port.is_output:
+                        event_args = (port_name, cport_name)
+                    else:
+                        event_args = (cport_name, port_name)
+                    
+                    self.patch_event_queue.add(event, *event_args)
+
+            except BaseException as e:
+                _logger.debug(
+                    f'New port {port_name} seems to already have connections '
+                    f'but getting theses ports failed\n'
+                    f'{str(e)}')
 
         @self.client.set_port_connect_callback
         def port_connect(port_a: jack.Port, port_b: jack.Port, connect: bool):
@@ -695,10 +730,12 @@ class PatchEngine:
             
         @self.client.set_blocksize_callback
         def blocksize(size: int):
+            _logger.debug(f'buffer size changed to {size}')
             self.patch_event_queue.add(PatchEvent.BLOCKSIZE_CHANGED, size)
             
         @self.client.set_samplerate_callback
         def samplerate(samplerate: int):
+            _logger.debug(f'samplerate changed to {samplerate}')
             self.patch_event_queue.add(
                 PatchEvent.SAMPLERATE_CHANGED, samplerate)
             
